=== modified file 'colordiff.py'
--- colordiff.py	2006-06-21 13:26:59 +0000
+++ colordiff.py	2006-06-21 13:51:45 +0000
@@ -16,12 +16,13 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import sys
+from os.path import expanduser
 
 from bzrlib.builtins import cmd_diff
 from bzrlib.patches import (hunk_from_header, InsertLine, RemoveLine,
                             ContextLine, Hunk)
 
-from terminal import colorstring
+import terminal
 
 class LineParser(object):
     def parse_line(self, line):
@@ -36,11 +37,50 @@
         else:
             return line
 
+
 class DiffWriter(object):
+
+    colors = {
+        'modline' :     'darkyellow',
+        'newtext' :     'darkgreen',
+        'oldtext' :     'red',
+        'diffstuff' :   'darkblue'
+    }
+
     def __init__(self, target):
         self.target = target
         self.lp = LineParser()
         self.chunks = []
+        self._read_colordiffrc()
+
+    def _read_colordiffrc(self):
+        path = expanduser('~/.colordiffrc')
+        try:
+            f = open(path, 'r')
+        except IOError:
+            return
+
+        for line in f.readlines():
+            try:
+                key, val = line.split('=')
+            except ValueError:
+                continue
+
+            key = key.strip()
+            val = val.strip()
+
+            tmp = val
+            if val.startswith('dark'):
+                tmp = val[4:]
+
+            if tmp not in terminal.colors:
+                continue
+
+            self.colors[key] = val
+
+    def colorstring(self, type, string):
+        color = self.colors[type]
+        self.target.write(terminal.colorstring(str(string), color))
 
     def write(self, text):
         newstuff = text.split('\n')
@@ -52,14 +92,14 @@
     def _writeline(self, line):
         item = self.lp.parse_line(line)
         if isinstance(item, Hunk):
-            self.target.write(colorstring(str(item), 'darkblue'))
+            self.colorstring('diffstuff', str(item))
         elif isinstance(item, InsertLine):
-            self.target.write(colorstring(str(item), 'darkgreen'))
+            self.colorstring('newtext', str(item))
         elif isinstance(item, RemoveLine):
-            self.target.write(colorstring(str(item), 'red'))
+            self.colorstring('oldtext', str(item))
         elif isinstance(item, basestring):
             if item.startswith('==='):
-                self.target.write(colorstring(item, 'darkyellow'))
+                self.colorstring('modline', str(item))
             else:
                 self.target.write(item)
         else:

